autowisp.fit_expression.used_var_finder module — AutoWISP documentation

# autowisp.fit_expression.used_var_finder module

## Class Inheritance Diagram

Define dict-like class tracking vars used when evaluating fit expressions.

class autowisp.fit_expression.used_var_finder.UsedVarFinder(default_symtable)

  Bases: `object`

  Record the names of all keys not in default symtable ever requested.

  __contains__(key)

    Is the given key in either the default symtable or data dtype.

  __getitem__(key)

    1.0 if key is one of the data otherwise default symtable entry

  __init__(default_symtable)

    Set the symtable before data is given and dtype to track usage of.

  get_used_vars()

    Return the names of the variables used so far.